package com.acquisition;


import com.acquisition.config.HttpRequestSender;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.system.ApplicationHome;
import org.springframework.context.ConfigurableApplicationContext;
import org.springframework.core.env.Environment;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Scanner;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


@SpringBootApplication

public class DataAcquisitionApplication {

    private static final Logger log = LoggerFactory.getLogger(DataAcquisitionApplication.class);
    public static void main(String[] args) throws UnknownHostException {
        System.out.println("DataAcquisition 程序启动...");

        ConfigurableApplicationContext configurableApplicationContext = SpringApplication.run(DataAcquisitionApplication.class, args);

        Environment env = configurableApplicationContext.getEnvironment();
        String ip = InetAddress.getLocalHost().getHostAddress();
        String port = env.getProperty("server.port");
        String path = env.getProperty("server.servlet.context-path");
        ApplicationHome home = new ApplicationHome(DataAcquisitionApplication.class);
        String filePath = home.getSource().getParentFile().getAbsolutePath();

        //        createFolder();

        log.info("\n-------------------------------------------------------------------\n\t" +
                "经济运行系统启动成功，访问路径如下:\n\t" +
                "本地路径: \t\thttp://localhost:" + port + path + "\n\t" +
                "网络地址: \t\thttp://" + ip + ":" + port + path + "\n\t" +
                "API文档: \t\thttp://" + ip + ":" + port + path + "/swagger-ui.html\n" +
                "-----------------------------------------------------------------------");
        log.info(filePath);
        System.out.println("Hello World!");

        Scanner scanner = new Scanner(System.in);

        while (true) {
            System.out.println("请选择要执行的操作：");
            System.out.println("1. 开始生成data文件夹");
            System.out.println("2. 开始修改配置");
            System.out.println("3. 开始修改104转发协议测点");
            System.out.println("4. 退出程序——直接叉掉");

            System.out.print("请输入选项（1/2/3/4）：");
            String choice = scanner.nextLine();

            switch (choice) {
                case "1":
                    try {
                        String firstResponse = HttpRequestSender.sendGetRequest("http://localhost:8080/data-acquisition/fileprocess");
                        System.out.println("开始生成data文件夹：" + firstResponse);
                    } catch (Exception e) {
                        System.err.println("生成data文件夹失败：" + e.getMessage());
                    }
                    break;
                case "2":
                    try {
                        String secondResponse = HttpRequestSender.sendGetRequest("http://localhost:8080/data-acquisition/fileprocessconfig");
                        System.out.println("开始修改配置：" + secondResponse);
                    } catch (Exception e) {
                        System.err.println("修改配置失败：" + e.getMessage());
                    }
                    break;
                case "3":
                    try {
                        String secondResponse = HttpRequestSender.sendGetRequest("http://localhost:8080/data-acquisition/copyfiledata");
                        System.out.println("开始修改配置：" + secondResponse);
                    } catch (Exception e) {
                        System.err.println("修改配置失败：" + e.getMessage());
                    }
                    break;
                case "4":
                    System.out.println("程序退出。");
                    scanner.close();
                    return;
                default:
                    System.out.println("无效的选项，请重新选择。");
            }
        }
    }

}
