package com.acquisition.config;


import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.FileInputStream;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.ArrayList;
import java.util.List;

public class FileUtils {

    // 读取 Excel 中指定列的数据

    public static List<String> readExcelColumn(String excelPath, int columnIndex) throws Exception {
        List<String> columnData = new ArrayList<>();

        try (FileInputStream fis = new FileInputStream(excelPath);
             Workbook workbook = new XSSFWorkbook(fis)) {
            Sheet sheet = workbook.getSheetAt(0); // 获取第一个工作表
            int firstRow = sheet.getFirstRowNum();
            int lastRow = sheet.getLastRowNum();

            for (int i = firstRow; i <= lastRow; i++) {
                Row row = sheet.getRow(i);
                String cellValue = "";
                if(row != null){
                    Cell cell = row.getCell(columnIndex);
                    cellValue =  getCellValueAsString(cell);
                }
                columnData.add(cellValue);
            }
        }
        return columnData;
    }

    private static String getCellValueAsString(Cell cell) {
        if (cell == null || cell.getCellType() == CellType.BLANK) {
            return "无";
        }

        switch (cell.getCellType()) {
            case STRING:
                return cell.getStringCellValue().trim();
            case NUMERIC:
                if (DateUtil.isCellDateFormatted(cell)) {
                    return cell.getDateCellValue().toString().trim();
                }else{
                    return String.valueOf(cell.getNumericCellValue()).trim();
                }
            case BOOLEAN:
                return String.valueOf(cell.getBooleanCellValue()).trim();
            case FORMULA:
                return cell.getCellFormula().trim();
            default:
                return cell.toString().trim();
        }
    }
    public static void createDirectory(String directoryPath) throws IOException {
        Path path = Paths.get(directoryPath);
        if (!Files.exists(path)) {
            Files.createDirectories(path);
        }
    }

    public static void copyFolderContent(String sourceDir, String targetDir) throws IOException {
        Path sourcePath = Paths.get(sourceDir);
        Path targetPath = Paths.get(targetDir);

        if (!Files.exists(sourcePath) || !Files.isDirectory(sourcePath)) {
            System.err.println("源目录不存在或不是目录: " + sourceDir);
            return; // 源目录不存在或不是目录，则直接返回
        }

        Files.walk(sourcePath).forEach(source -> {
                    Path target = targetPath.resolve(sourcePath.relativize(source));
                    try {
                        if (Files.isDirectory(source)) {
                            if(!Files.exists(target)){
                                Files.createDirectories(target);
                            }
                        } else {
                            Files.copy(source, target, StandardCopyOption.REPLACE_EXISTING);
                        }
                    }catch (IOException ex){
                        System.err.println("拷贝文件失败, 源文件: " + source + ", 目标文件: " + target + " " + ex.getMessage());
                    }
                }
        );
    }
}
