package com.acquisition.service.DataAcquisition;

import com.acquisition.config.FileUtils;

import com.alibaba.excel.util.StringUtils;
import org.springframework.stereotype.Service;

import java.io.File;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class FileProcessorService {

    private final String collectionServiceDir;

    public FileProcessorService() {
        // 动态获取用户桌面的路径
        this.collectionServiceDir = System.getProperty("user.home") + "/Desktop/CollectionService";
    }


    /**
     * 创建data文件并复制demo文件
     *
     * @throws Exception
     */
    public void processFiles1() throws Exception {
        String configExcelPath = collectionServiceDir + "/demo/config.xlsx";

        // 各字段列索引
        int[] columnIndexes = {6, 14, 20, 22, 25}; // 对应采集服务名、三区转发服务等

        String[] sourceFolders = {
                "gyee_syz_cj",
                "gyee_syz_zf",
                "gyee_syz_redis",
                "gyee_syz_fs",
                "gyee_syz_js"
        };
        Map<String, Boolean> copiedDirs = new HashMap<>();
        // 读取每列数据并处理
        for (int i = 0; i < columnIndexes.length; i++) {
            List<String> folderNames = FileUtils.readExcelColumn(configExcelPath, columnIndexes[i]);

            for (int j = 1; j < folderNames.size(); j++) {
                String folderName = folderNames.get(j);
                // 如果数据为空或为“无”，跳过当前行
                if (StringUtils.isBlank(folderName) || "无".equals(folderName)) {
                    continue;
                }
                String targetDir = collectionServiceDir + "/data" + (j) + "/" + folderName;
                if (!copiedDirs.containsKey(targetDir)) {
                    FileUtils.createDirectory(targetDir);
                    String sourceDir = collectionServiceDir + "/demo/" + sourceFolders[i];
                    FileUtils.copyFolderContent(sourceDir, targetDir);
                    copiedDirs.put(targetDir, true);
                }
            }
        }
    }


    /**
     * 增加在 demo 目录中查找与 folderName 匹配的 Excel 文件
     * @throws Exception
     */
    public void processFiles() throws Exception {
        String configExcelPath = collectionServiceDir + "/demo/config.xlsx";

        // 各字段列索引
        int[] columnIndexes = {6, 14, 20, 22, 25}; // 对应采集服务名、三区转发服务等

        String[] sourceFolders = {
                "gyee_syz_cj",
                "gyee_syz_zf",
                "gyee_syz_redis",
                "gyee_syz_fs",
                "gyee_syz_js"
        };
        Map<String, Boolean> copiedDirs = new HashMap<>();

        // 读取每列数据并处理
        for (int i = 0; i < columnIndexes.length; i++) {
            List<String> folderNames = FileUtils.readExcelColumn(configExcelPath, columnIndexes[i]);

            for (int j = 1; j < folderNames.size(); j++) {
                String folderName = folderNames.get(j);
                // 如果数据为空或为“无”，跳过当前行
                if (StringUtils.isBlank(folderName) || "无".equals(folderName)) {
                    continue;
                }

                String targetBaseDir = collectionServiceDir + "/data" + j;
                String targetDir = targetBaseDir + "/" + folderName;

                if (!copiedDirs.containsKey(targetDir)) {
                    // 创建目标目录
                    FileUtils.createDirectory(targetDir);

                    // 复制 demo 模板目录内容
                    String sourceDir = collectionServiceDir + "/demo/" + sourceFolders[i];
                    FileUtils.copyFolderContent(sourceDir, targetDir);
                    copiedDirs.put(targetDir, true);
                }

                // 在 demo 目录中查找与 folderName 匹配的 Excel 文件
                File demoDir = new File(collectionServiceDir + "/demo");
                File[] matchingFiles = demoDir.listFiles((dir, name) ->
                        name.toLowerCase().endsWith(".xlsx") && name.contains(folderName)
                );

                if (matchingFiles != null) {
                    for (File excelFile : matchingFiles) {
                        Path targetPath = Paths.get(targetBaseDir, excelFile.getName());
                        Files.copy(excelFile.toPath(), targetPath, StandardCopyOption.REPLACE_EXISTING);
                    }
                }
            }
        }
    }

}