package com.acquisition.service.DataAcquisition;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.ArrayList;
import java.util.List;

@Service
public class FilesdataCopy {

    private final String collectionServiceDir;

    public FilesdataCopy() {
        this.collectionServiceDir = System.getProperty("user.home") + "/Desktop/CollectionService";
    }

    public void processFiles() throws Exception {
        String inputPath = collectionServiceDir + "/demo/配置总表.xlsx";
        String outputPath = collectionServiceDir + "/104转发协议测点.xlsx";

        FileInputStream fis = new FileInputStream(new File(inputPath));
        Workbook inputWorkbook = new XSSFWorkbook(fis);
        Sheet inputSheet = inputWorkbook.getSheetAt(0);

        Workbook outputWorkbook = new XSSFWorkbook();
        Sheet outputSheet = outputWorkbook.createSheet("Sheet1");

        // 写入表头
        String[] headers = {"id", "测点", "测点类型", "公共地址", "104地址", "系数", "场站简称", "测点描述"};
        Row headerRow = outputSheet.createRow(0);
        for (int i = 0; i < headers.length; i++) {
            headerRow.createCell(i).setCellValue(headers[i]);
        }

        List<String> mongoKeys = new ArrayList<>();
        List<String> names = new ArrayList<>();

        int mongoKeyCol = 19; // T列 (索引从0开始)
        int nameCol = 0;      // 名称列 assumed to be 第1列

        for (int i = 1; i <= inputSheet.getLastRowNum(); i++) {
            Row row = inputSheet.getRow(i);
            if (row == null) continue;

            Cell mongoKeyCell = row.getCell(mongoKeyCol);
            Cell nameCell = row.getCell(nameCol);

            if (mongoKeyCell == null || nameCell == null) continue;

            mongoKeys.add(mongoKeyCell.toString().trim());
            names.add(nameCell.toString().trim());
        }

        int id = 1;
        int ai104Addr = 16385, di104Addr = 1;
        int aiPublicAddr = 1, diPublicAddr = 1;
        int aiCount = 0, diCount = 0;

        for (int i = 0; i < mongoKeys.size(); i++) {
            String mongoKey = mongoKeys.get(i);
            String name = names.get(i);

            String pointType = "";
            int lastUnderscoreIndex = mongoKey.lastIndexOf('_');
            if (lastUnderscoreIndex != -1 && lastUnderscoreIndex < mongoKey.length() - 1) {
                String suffix = mongoKey.substring(lastUnderscoreIndex + 1).toUpperCase();
                if (suffix.startsWith("AI") || suffix.startsWith("PI")) {
                    pointType = "AI";
                } else if (suffix.startsWith("DI")) {
                    pointType = "DI";
                }
            }


            String pointTypeUpper = pointType.toUpperCase();

            int current104Addr;
            int currentPublicAddr;

            if ("AI".equals(pointTypeUpper)) {
                current104Addr = ai104Addr;
                currentPublicAddr = aiPublicAddr;
                ai104Addr++;
                aiCount++;
                if (ai104Addr > 24384) {
                    ai104Addr = 16385;
                    aiPublicAddr++;
                }
            } else if ("DI".equals(pointTypeUpper)) {
                current104Addr = di104Addr;
                currentPublicAddr = diPublicAddr;
                di104Addr++;
                diCount++;
                if (di104Addr > 16000) {
                    di104Addr = 1;
                    diPublicAddr++;
                }
            } else {
                continue; // 跳过无法识别类型的行
            }

            Row outputRow = outputSheet.createRow(id);
            outputRow.createCell(0).setCellValue(id);                         // id
            outputRow.createCell(1).setCellValue(mongoKey);                  // 测点
            outputRow.createCell(2).setCellValue(pointTypeUpper);            // 测点类型
            outputRow.createCell(3).setCellValue(currentPublicAddr);         // 公共地址
            outputRow.createCell(4).setCellValue(current104Addr);            // 104地址
            outputRow.createCell(5).setCellValue(1);                         // 系数
            outputRow.createCell(6).setCellValue("GYEE");               // 分公司简称
            outputRow.createCell(7).setCellValue(name);                      // 测点描述

            id++;
        }

        FileOutputStream fos = new FileOutputStream(outputPath);
        outputWorkbook.write(fos);
        fos.close();

        inputWorkbook.close();
        outputWorkbook.close();

        System.out.println("处理完成，总共写入测点：" + (id - 1));
    }
}